<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 11:36:11 AM
 * @version $Rev$
 */

use Carerix\Api\Rest\Client;
use Carerix\Api\Rest\Entity;
use Carerix\Api\Rest\Entity\CRMedium;
use Carerix\Api\Rest\Manager;

/**
 * Settings class
 * Used to ....
 */
class Admin_Settings extends WP_Page {

    protected $interfacer = null;

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

    public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_settings_page';
    }

    public function getMenuTitle() { // as the tab
        return 'Settings';
    }

    public function getPageTitle() {
        return 'Settings';
    }

    public function page() {

//        Environment_Installation::clear_categories();

        Environment_Installation::isSane();

        $input_data = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);

        $settingsTable = new WP_Table(Environment_Installation::TABLE_SETTINGS);

        $tdata = array();
        $tdata['page_error'] = false;
        $tdata['credentials_changed'] = false;
        $tdata['app_token_error'] = false;
        if ($input_data !== NULL && wp_verify_nonce($input_data['_carerix_nonce_field'], 'settings')) {

            if (isset($input_data['app_name']) && trim($input_data['app_name']) != '') {
                $data = array(
                    'key' => 'app_name',
                    'value' => $input_data['app_name']
                );

                $valuesInDB = $settingsTable->getByKey('app_name');
                if (count($valuesInDB) >= 1) {
                    if ($valuesInDB[0]['value'] != $input_data['app_name']) {
                        $tdata['credentials_changed'] = true;
                    }
                    $record = $valuesInDB[0];
                    $settingsTable->update($record['id'], $data);
                } else {
                    $tdata['credentials_changed'] = true;
                    $settingsTable->insert($data);
                }
            } else {
                $tdata['page_error'] = true;
                $tdata['app_name_error'] = true;
            }

            if (isset($input_data['app_token']) && trim($input_data['app_token']) != '') {
                $data = array(
                    'key' => 'app_token',
                    'value' => $input_data['app_token']
                );

                $valuesInDB = $settingsTable->getByKey('app_token');
                if (count($valuesInDB) >= 1) {
                    if ($valuesInDB[0]['value'] != $input_data['app_token']) {
                        $tdata['credentials_changed'] = true;
                    }

                    $record = $valuesInDB[0];
                    $settingsTable->update($record['id'], $data);
                } else {
                    $tdata['credentials_changed'] = true;
                    $settingsTable->insert($data);
                }
            } else {
                $tdata['page_error'] = true;
                $tdata['app_token_error'] = true;
            }

            if (isset($input_data['app_reporting'])) {
                $data = array(
                    'key' => 'app_reporting',
                    'value' => $input_data['app_reporting']
                );

                $valuesInDB = $settingsTable->getByKey('app_reporting');
                if (count($valuesInDB) >= 1) {
                    $record = $valuesInDB[0];
                    $settingsTable->update($record['id'], $data);
                } else {
                    $settingsTable->insert($data);
                }
                $tdata['app_reporting'] = $input_data['app_reporting'];
            } else {
                $data = array(
                    'key' => 'app_reporting',
                    'value' => 'off'
                );

                $valuesInDB = $settingsTable->getByKey('app_reporting');
                if (count($valuesInDB) >= 1) {
                    $record = $valuesInDB[0];
                    $settingsTable->update($record['id'], $data);
                } else {
                    $settingsTable->insert($data);
                }
                $tdata['app_reporting'] = 'off';
            }

            if (isset($input_data['sync_clean'])) {
                Environment_Settings::setSyncCleanEmptyCategories($input_data['sync_clean']);
                $tdata['sync_clean'] = 'on';
            } else {
                Environment_Settings::setSyncCleanEmptyCategories('false');
                $tdata['sync_clean'] = 'off';
            }

            if (isset($input_data['skip_main_category'])) {
                Environment_Settings::setSkipMainCategory($input_data['skip_main_category']);
                $tdata['skip_main_category'] = 'on';
            } else {
                Environment_Settings::setSkipMainCategory('false');
                $tdata['skip_main_category'] = 'off';
            }

            if (isset($input_data['seo_skip_yoast_meta'])) {
                Environment_Settings::setSkipYoastMeta($input_data['seo_skip_yoast_meta']);
                $tdata['seo_skip_yoast_meta'] = 'on';
            } else {
                Environment_Settings::setSkipYoastMeta('false');
                $tdata['seo_skip_yoast_meta'] = 'off';
            }

            if (isset($input_data['dev_logging'])) {
                Environment_Settings::setDevLogging($input_data['dev_logging']);
                $tdata['dev_logging'] = 'on';
            } else {
                Environment_Settings::setDevLogging('false');
                $tdata['dev_logging'] = 'off';
            }

            $prev_restapisync_setting = Environment_Settings::getRestApiSync() ? "on" : "off";
            if (isset($input_data['restapisync_enabled'])) {
                Environment_Settings::setRestApiSync($input_data['restapisync_enabled']);
                $tdata['restapisync_enabled'] = 'on';
            } else {
                Environment_Settings::setRestApiSync('false');
                $tdata['restapisync_enabled'] = 'off';
            }
            if ( $tdata['restapisync_enabled'] != $prev_restapisync_setting ) {
	            $cronCleaner = new Utils_CronCleaner(0);
	            $cronCleaner->clearRestApiSyncStatuses();
            }
        }

        // try to set up the rest manager only if there is no user input error
        if (!$tdata['page_error']) {
            $tdata['app_name'] = Environment_Installation::getAppName();
            $tdata['app_token'] = Environment_Installation::getAppToken();
            $tdata['app_reporting'] = Environment_Installation::getAppReporting();
            $tdata['sync_clean'] = Environment_Settings::getSyncCleanEmptyCategories();
            $tdata['skip_main_category'] = Environment_Settings::getSkipMainCategory();
            $tdata['restapisync_enabled'] = Environment_Settings::getRestApiSync();
            $tdata['seo_skip_yoast_meta'] = Environment_Settings::getSkipYoastMeta();
            $tdata['dev_logging'] = Environment_Settings::getDevLogging();

            $exception = false;
            try {
                // reset manager with new credentials

                $client = new Client();
                $manager = new Manager($client);
                $manager->autoDiscoverEntities();
                $manager->setUrl(WP_Constants::CARERIX_API_ENDPOINT);
                $_app_name = Environment_Installation::getAppName();
                $_app_token = Environment_Installation::getAppToken();

                $manager->setUsername($_app_name);
                $manager->setPassword($_app_token);
                Entity::setManager($manager);

                $params = array(
                    'start' => '0',
                    'count' => '1'
                );
                CRMedium::findAll($params);
            } catch (Carerix\Api\Rest\Exception $care) {
                $tdata['error'] = $care->getMessage();
                $exception = $care;
            } catch (Exception $ex) {
                $tdata['error'] = $ex->getMessage();
                $exception = $ex;
            }
            if ($exception) {
                Utils_Log::write(Utils_Log::TYPE_AUTH, false, $exception);
                $tdata['app_token_error'] = true;
            } else {

                // Add the default source job only if somebody triggered the save button
                // 
                // Add the default open application page only if somebody triggered the save button
                // 
                // also, run manually the cron mechanism
                if ($input_data != null) {
                    $data['success'] = true;
                    Entity_Source_Job::addDefaultJobSource();

                    /* $cronRunner = new Environment_CronRunner();
                      $cronRunner->run(); */

                    Entity_Form_Apply::createDefaultPage();
                }
            }
        }

        $generalTemplate = new Utils_Template('admin/settings');
        $generalTemplate->with($tdata)->display();
    }

}
