<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 29, 2013 1:08:16 PM
 * @version $Rev$
 */

use Carerix\Api\Rest\Entity\CRPublication;

/**
 * Job class
 * Used to create a page from a publication ID
 */
class Entity_Cron_Promotional extends Entity_Cron {

	protected $usesUrl = false;
	
	protected $show = array('publicationID','publicationStart','creationDate', 'applicationContactInformation', 
		'companyInformation', 'functionContactInformation', 'introInformation',
		'layoutInstruction', 'notes', 'offerInformation', 'publicationSpecifications',
		'requirementsInformation', 'titleInformation', 'vacancyInformation', 'workLocation',
		'toMedium.code','toVacancy.vacancyID', 'toVacancy.jobTitle'
		);
	
	public function getUrl() {
	}

	public function process($data) {
        Utils_Cache::cleanEnvironment();
		$data = $data;

		if( ! $this->interfacer->wpml_is_active())
		{
			/**
			 * if the wpml is not active, create only one page
			 */
			$publication = $this->retrievePromotionalPublication($this->sourceData['settings']['publication_id']);
			$formatted = $this->prepareData($publication);
			$promotional = new Entity_Writer_Promotional($formatted);
            $promotional->setIntroText(@$this->sourceData['settings']['introtext']);
			$this->afterFinishData['title'] = $promotional->getTitle();
			$promotional_id = $promotional->write();
			$this->interfacer->entity_set_property( $promotional_id, 
													'source', 
													$this->sourceData['id'] );
		}
		else
		{
			/**
			 * if the wpml is active, finds related publications that 
			 * are possible translations and creates a writer for each one.
			 */
			$publication_translations = $this->findRelatedPublications($this->sourceData['settings']['publication_id']);
			
			
			foreach($publication_translations as $language => $publication)
			{
				$formatted = $this->prepareData($publication);
				$promotional_translation = new Entity_Writer_Promotional($formatted);
                $promotional_translation->setIntroText(@$this->sourceData['settings']['introtext']);
				if(!isset($this->afterFinishData['title'])) $this->afterFinishData['title'] = $promotional_translation->getTitle();
				$promotional_id = $promotional_translation->write();
				$this->interfacer->entity_set_property( $promotional_id, 
													'source', 
													$this->sourceData['id']);
				$trid = (int)$this->sourceData['id'] * 10000;
				$this->interfacer->wpml_register_translation($promotional_id, 
											$trid, 'post_page', $language);
			}
		}
	}
	
	public function retrievePromotionalPublication($publication_id)
	{
		$publicationID = (int)$publication_id;
		$params = array('show' => $this->show );
		try {
			$publication = CRPublication::find($publicationID, $params);
		} 
		catch (Carerix\Api\Rest\Exception $care)
		{
			throw new Exception('Publication not found');
			Utils_Log::write(Utils_Log::TYPE_FETCH_PUBLICATION, $publication, $care);
		}
		
		return $publication;
	}
	
	public function prepareData($publication)
	{
		
		$data = array();
		foreach($this->show as $path)
		{
			$turn = array_map('trim', array_filter(explode('.', $path)));
			
			$value = $publication;
			for($i = 0; $i < count($turn); $i++)
			{
				$value = $value->$turn[$i];
			}
			
			$data[$path] = $value;
		}
		return $data;
	}
	
	private function findRelatedPublications($publication_id)
	{
		$params = array('show'=>array('toMedium.code', 'toVacancy.vacancyID'));
		
		try {
			$publication = CRPublication::find($publication_id, $params);
		} 
		catch (Carerix\Api\Rest\Exception $care)
		{
			Utils_Log::write(Utils_Log::TYPE_FETCH_PUBLICATION, $publication, $care);
		}
		
		$related_publications = array();
		$vacancy_id = $publication->toVacancy->vacancyID;
		
		if($vacancy_id == null)
		{
			Utils_Log::write(Utils_Log::TYPE_NO_VACANCY, $publication);
			
			return $related_publications;
		}
		
		$related_publications_params = array(
			'start' => 0,
			'count' => 999,
			'show'  => array_merge(
							$this->show, 
							array('titleInformation', 'toMedium.code', 'toVancancy.vacancyID')),
			'qualifier' => "toVacancy.deleted != 1 and toVacancy.vacancyID = $vacancy_id",
		);
		
		try {
			$publications = CRPublication::findAll($related_publications_params);
		} catch (Carerix\Api\Rest\Exception $care)
		{
			Utils_Log::write(Utils_Log::TYPE_FETCH_PUBLICATION, $publications, $care);
		}
		
		foreach($publications as $publication)
		{
			$related_publications[$this->language_extractor($publication->toMedium->code)] = $publication;
		}
		return $related_publications;
	}
	
	private function language_extractor($medium)
	{
		$default_language = strtolower($this->interfacer->language_major_current());
		$parts = explode('-', $medium);
		if(count($parts) <= 1)
		{
			return $default_language;
		}
		
		$language_code = $parts[count($parts)-1];
		if(strlen($language_code) >= 2) return $language_code;
		
		return $default_language;
	}
	
	public function getAfterData()
	{
		return $this->afterFinishData;
	}
}