<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 2, 2013 1:45:22 PM
 * @version $Rev$
 */


/**
 * Form class
 * Used to manipulate the forms table
 */
class Entity_Form {
	
	private $id = false;
	private $formTable = null;
	private $interfacer = null;
	protected $type = false;
	
	/**
	 * 
	 * @param int $id the id of the form
	 */
	public function __construct($id = false) {
		$this->id = $id;
		
		$this->interfacer = WP_Interfacer::getInstance();
		
		$this->formTable = new WP_Table(Environment_Installation::TABLE_FORMS);
		
		if($this->id)
		{
			$this->formTable->getByID($id);
		}
	}
	
	/**
	 * Saves form data
	 * If the object has an id, it updates it, otherwise inserts it
	 * 
	 * @param array $data
	 */
	public function save($data)
	{
		$data = $this->prepare($data);
		if($this->id)
		{
			$this->formTable->update($this->id, $data);
		}
		else
		{
			$this->id = $this->formTable->insert($data);
		}
	}
	
	public function getID()
	{
		return $this->id;
	}
	
	public function getData()
	{
		return $this->formTable->getByID($this->id);
	}
	
	public function getType()
	{
		return $this->type;
	}
	
	public function delete()
	{
		$this->formTable->delete($this->id);
	}
	
	
	private function prepare($data)
	{
		if(!is_array($data)) return;
		
		$current_user_id = $this->interfacer->user_current_id();
		$current_user_name = $this->interfacer->user_current_name();
		$date = $this->interfacer->user_current_time();
		
		$data['author_id'] = $current_user_id;
		$data['author_name'] = $current_user_name;
		$data['date'] = $date;
		
		$name = $data['post_title'];
		unset($data['post_title']);
		
		$save_data = array(
			'type' => $this->getType(),
			'name' => $name,
			'settings' => serialize($data)
		);
		
		return $save_data;
	}

	/**
	 * Renders the Agreement Checkbox used on the (open) application form and job alert form
	 *
	 * @param false $disabled
	 *
	 * @return string
	 */
	static function _agree_html($disabled = false) {
		$agreementText = Environment_Settings::getFormGeneralAgreement();
		$agreementLabel = Environment_Settings::getFormGeneralAgreementLabel();
		$agreementUrl = Environment_Settings::getFormGeneralAgreementUrl();
		$checked = '';
		$disabled = $disabled ? 'disabled' : '';
		$agreeDiv = '';
		$agreeText = '';
		$labels = Utils_Labels::get();
		if (isset($_POST['_agreement_check'])) {
			$checked = 'checked';
		}

		if ($agreementLabel) {
			if ($agreementUrl) {
				$agreeText = "<div id='agreement_container'><label for='agreement_check'><input $disabled id='agreement_check' name='_agreement_check' type='checkbox' value='on' value='on' $checked />&nbsp;<a href='$agreementUrl' target='_blank'>$agreementLabel</a> </label></div>";
			} else if ($agreementText) {
				$agreeDiv = "<div id='agreement' style='display: none;'><p><button class='close_modal_carerix'>{$labels['general.button.close']}</button></p><p class='text'>$agreementText</p><p><button class='close_modal_carerix'>{$labels['general.button.close']}</button></p></div>";
				$agreeText = "<div id='agreement_container'><label for='agreement_check'><input $disabled id='agreement_check' name='_agreement_check' type='checkbox' value='on' value='on' $checked />&nbsp;<a href='#' id='show_agreement'>$agreementLabel</a> </label></div>";
			}
		}

		return $agreeDiv . $agreeText;
	}
}